"""
Kogna MCP Server - Multi-agent AI avatar room engine

A Model Context Protocol (MCP) server that provides tools for interacting
with Kogna's multi-agent AI avatar system.
"""

__version__ = "1.0.0"
__author__ = "Subbu Bhamidipati"
__email__ = "bhsubbu.1995@gmail.com" 